package com.ynet.life.sujrb.cache;

import com.ynet.gene.service.GENEService;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.sujrb.cache.coherence.CoherenceManager;
import com.ynet.life.sujrb.cache.memcached.MemcacheManager;
import java.io.IOException;
import java.util.Map;
import javax.sql.DataSource;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_sujrb_cache.jar:com/ynet/life/sujrb/cache/CacheService.class */
public class CacheService extends GENEService {
    private String type = null;
    private Cache cache = null;
    private CacheLoader cacheLoader = null;
    private int maxSize = 1000;
    private String JNDIDataSource;

    public Map<String, Object> load(String customerid, String bankid) {
        return load(customerid, bankid, false);
    }

    public Map<String, Object> load(String id, String bankid, boolean forceHitDb) {
        Map<String, Object> node = null;
        String key = String.valueOf(bankid) + "_" + id;
        if (StringUtils.isNotBlank(id) && StringUtils.isNotBlank(bankid)) {
            if (forceHitDb) {
                node = getCacheLoader().load(id, bankid);
                getCache().put(key, node);
            } else {
                Map<String, Object> map = getCache().get(key);
                node = map;
                if (map == null) {
                    node = getCacheLoader().load(id, bankid);
                    getCache().put(key, node);
                }
            }
        }
        return node;
    }

    public void invalidation(String id) {
        getCache().remove(id);
    }

    public boolean exist(String id) {
        return getCache().getData().containsKey(id);
    }

    public void initializeCache(DataSource dataSource) throws Exception {
        this.cacheLoader = new CustomerCacheLoader();
        if (dataSource == null) {
            Trace.logError("LifeAction", "缓存数据源初始化失败");
        } else {
            this.cacheLoader.init(dataSource);
        }
    }

    public int getNumberOfNodes() {
        return getCache().getData().size();
    }

    public boolean isFull() {
        return getNumberOfNodes() == this.maxSize;
    }

    public void clear() {
        getCache().clear();
    }

    public Cache getCache() {
        if (this.cache == null) {
            if (CacheConstants.CACHE_TYPE_LRUCACHE.equalsIgnoreCase(this.type)) {
                this.cache = new LRUCache();
                try {
                    this.cache.init(this.maxSize);
                } catch (IOException e) {
                    Trace.logError("LifeAction", "初始化缓存大小失败", e);
                }
            } else {
                getCache("");
            }
        }
        return this.cache;
    }

    public Cache getCache(String name) {
        if (this.cache != null) {
            if (this.cache.getCacheName().equals(name) || CacheConstants.CACHE_TYPE_LRUCACHE.equalsIgnoreCase(this.type)) {
                return this.cache;
            }
        } else if (CacheConstants.CACHE_TYPE_MEMCACHED.equalsIgnoreCase(this.type)) {
            this.cache = new MemcacheManager(name);
        } else if (CacheConstants.CACHE_TYPE_COHERENCE.equalsIgnoreCase(this.type)) {
            this.cache = new CoherenceManager(name);
        }
        return this.cache;
    }

    public void setCache(Cache cache) {
        this.cache = cache;
    }

    public CacheLoader getCacheLoader() {
        if (this.cacheLoader == null) {
            try {
                initializeCache((DataSource) LifeStandard.getRootContext().getService(this.JNDIDataSource));
            } catch (Exception e) {
                Trace.logError("LifeAction", "缓存初始化失败", e);
            }
        }
        return this.cacheLoader;
    }

    public void setCacheLoader(CacheLoader cacheLoader) {
        this.cacheLoader = cacheLoader;
    }

    public int getMaxSize() {
        return this.maxSize;
    }

    public void setMaxSize(int maxSize) {
        this.maxSize = maxSize;
    }

    public String getJNDIDataSource() {
        return this.JNDIDataSource;
    }

    public void setJNDIDataSource(String jNDIDataSource) {
        this.JNDIDataSource = jNDIDataSource;
    }

    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }
}
